//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/CatDevice/FootprintItemCatalog.h
//! @brief     Defines class FootprintItemCatalog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_CATDEVICE_FOOTPRINTITEMCATALOG_H
#define BORNAGAIN_GUI_MODEL_CATDEVICE_FOOTPRINTITEMCATALOG_H

#include <QString>
#include <QVector>

class FootprintItem;

class FootprintItemCatalog {
public:
    using CatalogedType = FootprintItem;

    // Do not change the numbering! It is serialized!
    enum class Type : uint8_t { None = 0, Gaussian = 1, Square = 2 };

    struct UiInfo {
        QString menuEntry;
        QString description;
    };

    //! Creates the item of the given type.
    static FootprintItem* create(Type type);

    //! Available types of items.
    //!
    //! Contains also type "None".
    //! This list is sorted as expected in the UI (e.g. in combo box)
    static QVector<Type> types();

    //! UiInfo on the given type.
    static UiInfo uiInfo(Type t);

    //! Returns the enum type of the given item.
    static Type type(const FootprintItem* item);
};

#endif // BORNAGAIN_GUI_MODEL_CATDEVICE_FOOTPRINTITEMCATALOG_H
