//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Job/FitSuiteItem.h
//! @brief     Defines class FitSuiteItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_JOB_FITSUITEITEM_H
#define BORNAGAIN_GUI_MODEL_JOB_FITSUITEITEM_H

#include "GUI/Model/BaseItem/SessionItem.h"

class FitParameterContainerItem;
class MinimizerContainerItem;

class BA_CORE_API_ FitSuiteItem : public QObject, public SessionItem {
    Q_OBJECT
private:
    static constexpr auto P_UPDATE_INTERVAL{"Update interval"};
    static constexpr auto P_ITERATION_COUNT{"Number of iterations"};
    static constexpr auto P_CHI2{"Chi2"};
    static constexpr auto T_FIT_PARAMETERS_CONTAINER{"Fit parameters container"};
    static constexpr auto T_MINIMIZER{"Minimizer settings"};

public:
    static constexpr auto M_TYPE{"FitSuite"};

    explicit FitSuiteItem();

    FitParameterContainerItem* createFitParametersContainer();
    FitParameterContainerItem* fitParameterContainerItem();

    MinimizerContainerItem* createMinimizerContainer();
    MinimizerContainerItem* minimizerContainerItem();

    int updateInterval() const;
    void setUpdateInterval(int interval);

    int iterationCount() const;
    void setIterationCount(int count);

    double chi2() const;
    void setChi2(double chi2);

signals:
    void iterationCountChanged(int count);
    void updateIntervalChanged(int interval);
};

#endif // BORNAGAIN_GUI_MODEL_JOB_FITSUITEITEM_H
