//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Fit/JobRealTimeWidget.cpp
//! @brief     Implements class JobRealTimeWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Fit/JobRealTimeWidget.h"
#include "GUI/Model/Job/JobItem.h"
#include "GUI/Model/Model/JobModel.h"
#include "GUI/View/Fit/ParameterTuningWidget.h"
#include "GUI/View/Tool/mainwindow_constants.h"
#include <QVBoxLayout>

namespace {

const bool reuse_widget = true;
}

JobRealTimeWidget::JobRealTimeWidget(JobModel* jobModel, QWidget* parent)
    : QWidget(parent)
    , m_stackedWidget(new ItemStackPresenter<ParameterTuningWidget>(reuse_widget))
{
    setWindowTitle(GUI::Constants::JobRealTimeWidgetName);
    setObjectName("JobRealTimeWidget");
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    auto* mainLayout = new QVBoxLayout;
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(0);
    mainLayout->addWidget(m_stackedWidget);
    setLayout(mainLayout);

    m_stackedWidget->setModel(jobModel);
}

ParameterTuningWidget* JobRealTimeWidget::parameterTuningWidget(JobItem* jobItem)
{
    return m_stackedWidget->itemWidget(jobItem);
}

QSize JobRealTimeWidget::sizeHint() const
{
    return QSize(GUI::Constants::REALTIME_WIDGET_WIDTH_HINT, 480);
}

QSize JobRealTimeWidget::minimumSizeHint() const
{
    return QSize(100, 100);
}

void JobRealTimeWidget::setJobItem(JobItem* jobItem)
{
    if (!isValidJobItem(jobItem)) {
        m_stackedWidget->hideWidgets();
        return;
    }
    m_stackedWidget->setItem(jobItem);
}

//! Returns true if JobItem is valid for real time simulation.

bool JobRealTimeWidget::isValidJobItem(JobItem* item)
{
    return item && (item->isCompleted() || item->isCanceled() || item->isFailed());
}
